@@ -1,7 +1,11 @@
 import logging
 from logging.config import dictConfig
 import os
+from os import path
 import sys
+import psutil
+from pathlib import Path
+import shutil
 import time
 from stem.control import Controller
 from .util.tor import stop_hidden_services, start_hidden_service
@@ -10,9 +14,10 @@ import click
 from .server import create_app, init_app
 from .helpers import set_loglevel
 
-from os import path
 import signal
 
+logger = logging.getLogger(__name__)
+
 
 @click.group()
 def cli():
@@ -38,6 +43,11 @@ def cli():
 def server(daemon, stop, restart, force, port, host, cert, key, debug, tor, hwibridge):
     # create an app to get Specter instance
     # and it's data folder
+    logger.info("Logging is hopefully configured")
+    if debug:
+        ca_logger = logging.getLogger("cryptoadvance")
+        ca_logger.setLevel(logging.DEBUG)
+        logger.debug("We're now on level DEBUG on logger cryptoadvance")
     app = create_app()
     app.app_context().push()
     init_app(app, hwibridge=hwibridge)
@@ -180,57 +190,134 @@ def server(daemon, stop, restart, force, port, host, cert, key, debug, tor, hwib
         run(debug=debug)
 
 
+class Echo:
+    def __init__(self, quiet):
+        self.quiet = quiet
+
+    def echo(self, mystring, prefix=True, **kwargs):
+        if self.quiet:
+            pass
+        else:
+            if prefix:
+                click.echo(f"    --> ", nl=False)
+            click.echo(f"{mystring}", **kwargs)
+
+
 @cli.command()
-@click.option("--debug/--no-debug", default=False)
-@click.option("--mining/--no-mining", default=True)
-@click.option("--docker-tag", "docker_tag", default="latest")
-def bitcoind(debug, mining, docker_tag):
+@click.option("--debug/--no-debug", default=False, help="Turns on debug-logging")
+@click.option("--quiet/--no-quiet", default=False, help="as less output as possible")
+@click.option(
+    "--nodocker", default=False, is_flag=True, help="use without docker (non-default)"
+)
+@click.option(
+    "--docker-tag", "docker_tag", default="latest", help="Use a specific docker-tag"
+)
+@click.option(
+    "--data-dir",
+    default="/tmp/bitcoind_plain_datadir",
+    help="specify a (maybe not yet existing) datadir. Works only in --nodocker (Default:/tmp/bitcoind_plain_datadir) ",
+)
+@click.option("--mining/--no-mining", default=True, help="Turns on mining (default)")
+@click.option(
+    "--mining-period",
+    default="15",
+    help="Every mining-period (in seconds), a block gets mined (default 15sec)",
+)
+@click.option(
+    "--reset",
+    is_flag=True,
+    default=False,
+    help="Will kill the bitcoind. Datadir will get lost.",
+)
+def bitcoind(
+    debug, quiet, nodocker, docker_tag, data_dir, mining, mining_period, reset
+):
+    """This will start a bitcoind regtest and mines a block every mining-period.
+    If a bitcoind is already running on port 18443, it won't start another one. If you CTRL-C this, the bitcoind will
+    still continue to run. You have to shut it down.
+    """
+    # In order to avoid these dependencies for production use, we're importing them here:
     import docker
+    from .bitcoind import (
+        BitcoindDockerController,
+        BitcoindPlainController,
+        fetch_wallet_addresses_for_mining,
+    )
 
-    from .bitcoind import BitcoindDockerController, fetch_wallet_addresses_for_mining
-
-    logging.getLogger().setLevel(logging.INFO)
-    mining_every_x_seconds = 15
     if debug:
-        logging.getLogger().setLevel(logging.DEBUG)
-    click.echo("    --> starting or detecting container")
-    my_bitcoind = BitcoindDockerController(docker_tag=docker_tag)
+        logging.getLogger("cryptoadvance").setLevel(logging.DEBUG)
+        logger.debug("Now on debug-logging")
+    echo = Echo(quiet).echo
+
+    if reset:
+        if not nodocker:
+            echo("ERROR: --reset only works in conjunction with --nodocker currently")
+            return
+        did_something = False
+
+        for proc in psutil.process_iter():
+            try:
+                # Get process name & pid from process object.
+                processName = proc.name()
+                pid = proc.pid
+                if processName.startswith("bitcoind"):
+                    echo(f"Killing bitcoind-process with id {pid} ...")
+                    did_something = True
+                    os.kill(pid, signal.SIGTERM)
+            except (psutil.NoSuchProcess, psutil.AccessDenied, psutil.ZombieProcess):
+                echo(f"Pid {pid} not owned by us. Might be a docker-process? {line}")
+        if Path(data_dir).exists():
+            echo(f"Purging Datadirectory {data_dir} ...")
+            did_something = True
+            shutil.rmtree(data_dir)
+        if not did_something:
+            echo("Nothing to do!")
+        return
+    logging.getLogger().setLevel(logging.INFO)
+    mining_every_x_seconds = float(mining_period)
+    if nodocker:
+        echo("starting plain bitcoind")
+        my_bitcoind = BitcoindPlainController()
+        # Make sure datadir does exist if specified:
+        Path(data_dir).mkdir(parents=True, exist_ok=True)
+    else:
+        echo("starting or detecting container")
+        my_bitcoind = BitcoindDockerController(docker_tag=docker_tag)
     try:
-        my_bitcoind.start_bitcoind()
+        my_bitcoind.start_bitcoind(cleanup_at_exit=True, datadir=data_dir)
     except docker.errors.ImageNotFound:
-        click.echo(f"    --> Image with tag {docker_tag} does not exist!")
-        click.echo(
-            f"    --> Try to download first with docker pull \
+        echo(f"Image with tag {docker_tag} does not exist!")
+        echo(
+            f"Try to download first with docker pull \
                      registry.gitlab.com/cryptoadvance/specter-desktop\
                      /python-bitcoind:{docker_tag}"
         )
         sys.exit(1)
-    tags_of_image = [
-        image.split(":")[-1] for image in my_bitcoind.btcd_container.image.tags
-    ]
-    if docker_tag not in tags_of_image:
-        click.echo(
-            "    --> The running docker container is not \
-                            the tag you requested!"
-        )
-        click.echo(
-            "    --> please stop first with docker stop {}".format(
-                my_bitcoind.btcd_container.id
+    if not nodocker:
+        tags_of_image = [
+            image.split(":")[-1] for image in my_bitcoind.btcd_container.image.tags
+        ]
+        if docker_tag not in tags_of_image:
+            echo(
+                "The running docker container is not \
+                                the tag you requested!"
             )
-        )
-        sys.exit(1)
-    click.echo("    --> containerImage: %s" % my_bitcoind.btcd_container.image.tags)
-    click.echo("    -->            url: %s" % my_bitcoind.rpcconn.render_url())
-    click.echo("    --> user, password: bitcoin, secret")
-    click.echo("    -->     host, port: localhost, 18443")
-    click.echo(
-        "    -->    bitcoin-cli: bitcoin-cli -regtest -rpcuser=bitcoin \
-            -rpcpassword=secret getblockchaininfo "
+            echo(
+                "please stop first with docker stop {}".format(
+                    my_bitcoind.btcd_container.id
+                )
+            )
+            sys.exit(1)
+        echo("containerImage: %s" % my_bitcoind.btcd_container.image.tags)
+    echo("           url: %s" % my_bitcoind.rpcconn.render_url())
+    echo("user, password: bitcoin, secret")
+    echo("    host, port: localhost, 18443")
+    echo(
+        "   bitcoin-cli: bitcoin-cli -regtest -rpcuser=bitcoin -rpcpassword=secret getblockchaininfo "
     )
     if mining:
-        click.echo(
-            "    --> Now, mining a block every %i seconds. \
-            Avoid it via --no-mining"
+        echo(
+            "Now, mining a block every %f seconds, avoid it via --no-mining"
             % mining_every_x_seconds
         )
         # Get each address some coins
@@ -243,40 +330,23 @@ def bitcoind(debug, mining, docker_tag):
 
         # make them spendable
         my_bitcoind.mine(block_count=100)
-        click.echo("    --> ", nl=False)
-        i = 0
+        echo(
+            f"height: {my_bitcoind.rpcconn.get_rpc().getblockchaininfo()['blocks']} | ",
+            nl=False,
+        )
+        i, j = 0, 0
         while True:
             my_bitcoind.mine()
-            click.echo("%i" % (i % 10), nl=False)
+            echo("%i" % (i % 10), prefix=False, nl=False)
             if i % 10 == 9:
-                click.echo(" ", nl=False)
+                echo(" ", prefix=False, nl=False)
             i += 1
             if i >= 50:
+                j = i
                 i = 0
-                click.echo(" ")
-                click.echo("    --> ", nl=False)
+                echo("", prefix=False)
+                echo(
+                    f"height: {my_bitcoind.rpcconn.get_rpc().getblockchaininfo()['blocks']} | ",
+                    nl=False,
+                )
             time.sleep(mining_every_x_seconds)
-
-
-if __name__ == "__main__":
-    # central and early configuring of logging see
-    # https://flask.palletsprojects.com/en/1.1.x/logging/#basic-configuration
-    dictConfig(
-        {
-            "version": 1,
-            "formatters": {
-                "default": {
-                    "format": "[%(asctime)s] %(levelname)s in %(module)s: %(message)s"
-                }
-            },
-            "handlers": {
-                "wsgi": {
-                    "class": "logging.StreamHandler",
-                    "stream": "ext://flask.logging.wsgi_errors_stream",
-                    "formatter": "default",
-                }
-            },
-            "root": {"level": "INFO", "handlers": ["wsgi"]},
-        }
-    )
-    cli()
