@@ -2,6 +2,7 @@ import json
 from .key import Key
 from .persistence import read_json_file, write_json_file
 import logging
+from .helpers import is_testnet
 
 logger = logging.getLogger()
 
@@ -9,11 +10,13 @@ logger = logging.getLogger()
 class Device:
     device_type = None  # this is saved to json
     name = "Unknown device"  # this is how device appears in UI
+    icon = "other_icon.svg"
 
     # override these vars to add support
     # of different communication methods
     sd_card_support = False
     qr_code_support = False
+    qr_code_support_verify = False
     hwi_support = False
     supports_hwi_toggle_passphrase = False
     supports_hwi_multisig_display_address = False
@@ -79,6 +82,8 @@ class Device:
         self.manager.update()
 
     def wallets(self, wallet_manager):
+        if wallet_manager is None:
+            return []
         wallets = []
         for wallet in wallet_manager.wallets.values():
             if self in wallet.devices:
@@ -92,9 +97,20 @@ class Device:
         self.manager.update()
 
     def key_types(self, network="main"):
-        test = network != "main"
+        test = is_testnet(network)
         return [key.key_type for key in self.keys if (key.is_testnet == test)]
 
+    def has_key_types(self, wallet_type, network="main"):
+        if wallet_type == "multisig":
+            for key_type in self.key_types(network):
+                if key_type in ["", "sh-wsh", "wsh"]:
+                    return True
+        elif wallet_type == "simple":
+            for key_type in self.key_types(network):
+                if key_type in ["", "sh-wpkh", "wpkh"]:
+                    return True
+        return "" in self.key_types(network)
+
     def __eq__(self, other):
         if other is None:
             return False
