@@ -71,4 +71,16 @@ window.addEventListener('beforeunload', function (e) {
 	window.setTimeout(()=>{
 		document.getElementById("pageloader").style.display = 'block';
 	}, 200);
-});
\ No newline at end of file
+});
+
+// toggle a navbar on mobile view
+function toggleMobileNav(btn, openImg, collapseImg) {
+	var x = btn.parentNode;
+	if (x.className === "row collapse-on-mobile") {
+		x.className += " responsive";
+		btn.children[0].src = collapseImg;
+	} else {
+		x.className = "row collapse-on-mobile";
+		btn.children[0].src = openImg;
+	}
+}
